@@ -11,7 +11,6 @@
 #include <Akonadi/MessageFlags>
 #include <KIMAP/CloseJob>
 #include <KIMAP/DeleteJob>
-#include <KIMAP/ExpungeJob>
 #include <KIMAP/SelectJob>
 #include <KIMAP/StoreJob>
 #include <KLocalizedString>
@@ -46,7 +45,7 @@ void RemoveCollectionRecursiveTask::onMailBoxesReceived(const QList<KIMAP::MailB
     // we use a map here that has the level of nesting as key.
     QMultiMap<int, KIMAP::MailBoxDescriptor> foldersToDelete;
 
-    for (int i = 0; i < descriptors.size(); ++i) {
+    for (int i = 0, total = descriptors.size(); i < total; ++i) {
         const KIMAP::MailBoxDescriptor descriptor = descriptors[i];
 
         if (descriptor.name == mailBox || descriptor.name.startsWith(mailBox + descriptor.separator)) { // a sub folder to delete
@@ -62,7 +61,11 @@ void RemoveCollectionRecursiveTask::onMailBoxesReceived(const QList<KIMAP::MailB
     mFolderFound = true;
 
     // Now start the actual deletion work
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     mFolderIterator.reset(new QMapIterator<int, KIMAP::MailBoxDescriptor>(foldersToDelete));
+#else
+    mFolderIterator.reset(new QMultiMapIterator<int, KIMAP::MailBoxDescriptor>(foldersToDelete));
+#endif
     mFolderIterator->toBack(); // we start with largest nesting value first
 
     deleteNextMailbox();
