@@ -26,7 +26,7 @@ public:
 
     void init(const QString &identifier);
 
-    qlonglong currentUserId() const;
+    Q_REQUIRED_RESULT qlonglong currentUserId() const;
 
     User lookupUid(qlonglong uid) const;
     User lookupEmail(const QString &email) const;
@@ -50,4 +50,3 @@ private:
     static Users *mSelf;
 };
 }
-
